﻿using System.Linq;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace UpdateMapStyles.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            Map map = new Map("Map1",
                new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage),
                new System.Web.UI.WebControls.Unit(100, System.Web.UI.WebControls.UnitType.Percentage));

            map.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#E5E3DF"));
            map.CurrentExtent = new RectangleShape(-125, 72, 50, -46);
            map.MapUnit = GeographyUnit.DecimalDegree;

            map.CustomOverlays.Add(new WorldMapKitWmsWebOverlay());

            InMemoryFeatureLayer layer = new InMemoryFeatureLayer();
            layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.County1;
            layer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            layer.InternalFeatures.Add(new Feature(new RectangleShape(-30, 30, 30, -30)));

            LayerOverlay layerOverlay = new LayerOverlay("DynamicOverlay");
            layerOverlay.IsBaseOverlay = false;
            layerOverlay.Layers.Add(layer);
            map.CustomOverlays.Add(layerOverlay);

            return View(map);
        }

        [MapActionFilter]
        public void UpdateStyle(Map map, GeoCollection<object> args)
        {
            LayerOverlay layerOverlay = map.CustomOverlays.OfType<LayerOverlay>().FirstOrDefault();
            InMemoryFeatureLayer layer = layerOverlay.Layers.OfType<InMemoryFeatureLayer>().FirstOrDefault();
            layer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush = new GeoSolidBrush(GeoColor.GetRandomGeoColor(RandomColorType.All));
        }
    }
}